<?php
/**
 * UTM Switcher
 *
 * @package   Utm_Switcher_Admin
 * @author    David Alberts and Jeff Shamley <mrrockgroin@gmail.com>
 * @license   GPL-2.0+
 * @link      https://jeffshamley.com
 * @copyright 2016 
 */

/**
 * Plugin class. This class should ideally be used to work with the
 * administrative side of the WordPress site.
 *
 * If you're interested in introducing public-facing
 * functionality, then refer to `class-utm-switcher.php`
 *
 * @package Utm_Switcher_Admin
 * @author  David Alberts and Jeff Shamley <mrrockgroin@gmail.com>
 */
class Utm_Switcher_Admin {

    /**
     * Instance of this class.
     *
     * @since    1.0.0
     *
     * @var      object
     */
    protected static $instance = null;

    /**
     * Slug of the plugin screen.
     *
     * @since    1.0.0
     *
     * @var      string
     */
    protected $plugin_screen_hook_suffix = null;

    /**
     * Initialize the plugin by loading admin scripts & styles and adding a
     * settings page and menu.
     *
     * @since     1.0.0
     */
    private function __construct() {

        /*
         * @TODO :
         *
         * - Uncomment following lines if the admin class should only be available for super admins
         */
        /* if( ! is_super_admin() ) {
          } */
        $plugin = Utm_Switcher::get_instance();
        $this->plugin_slug = $plugin->get_plugin_slug();
        $this->plugin_name = $plugin->get_plugin_name();
        $this->version = $plugin->get_plugin_version();
        $this->cpts = $plugin->get_cpts();

        add_action('carbon_register_fields', array($this, 'crb_register_custom_fields'));

        // Load admin style sheet and JavaScript.
//        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_styles'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));

        // Add the options page and menu item.
//        add_action('admin_menu', array($this, 'add_plugin_admin_menu'));

        // Add an action link pointing to the options page.
//        $plugin_basename = plugin_basename(plugin_dir_path(realpath(dirname(__FILE__))) . $this->plugin_slug . '.php');
//        add_filter('plugin_action_links_' . $plugin_basename, array($this, 'add_action_links'));

        /* Define custom functionality.
         *
         * Read more about actions and filters:
         * http://codex.wordpress.org/Plugin_API#Hooks.2C_Actions_and_Filters
         */


        /* Tag generator */
        add_action('admin_init', array($this, 'add_tag_generator_utm'), 35);


        /*
         * Load Wp_Admin_Notice for the notices in the backend
         * 
         * First parameter the HTML, the second is the css class
         */
        if (!class_exists('WP_Admin_Notice')) {
            require_once( plugin_dir_path(__FILE__) . 'includes/WP-Admin-Notice/WP_Admin_Notice.php' );
        }

    }

    /**
     * Return an instance of this class.
     *
     * @since     1.0.0
     *
     * @return    object    A single instance of this class.
     */
    public static function get_instance() {

        /*
         * @TODO :
         *
         * - Uncomment following lines if the admin class should only be available for super admins
         */
        /* if( ! is_super_admin() ) {
          return;
          } */

        // If the single instance hasn't been set, set it now.
        if (null == self::$instance) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    function crb_register_custom_fields() {
        include_once(UTM_SWITCHER_PLUGIN_PATH . '/includes/post-meta.php');
    }

    /**
     * Register and enqueue admin-specific style sheet.
     *
     * @since     1.0.0
     *
     * @return    null    Return early if no settings page is registered.
     */
    public function enqueue_admin_styles() {
        if (!isset($this->plugin_screen_hook_suffix)) {
            return;
        }

        $screen = get_current_screen();
        if ($this->plugin_screen_hook_suffix == $screen->id || strpos($_SERVER['REQUEST_URI'], 'index.php') || strpos($_SERVER['REQUEST_URI'], get_bloginfo('wpurl') . '/wp-admin/')) {
            wp_enqueue_style($this->plugin_slug . '-admin-styles', plugins_url('assets/css/admin.css', __FILE__), array('dashicons'), Utm_Switcher::VERSION);
        }
    }

    /**
     * Register and enqueue admin-specific JavaScript.
     *
     *
     * @since     1.0.0
     *
     * @return    null    Return early if no settings page is registered.
     */
    public function enqueue_admin_scripts() {
        if (!isset($this->plugin_screen_hook_suffix)) {
            return;
        }

        $screen = get_current_screen();
        if ($this->plugin_screen_hook_suffix == $screen->id) {
            wp_enqueue_script($this->plugin_slug . '-admin-script', plugins_url('assets/js/admin.js', __FILE__), array('jquery', 'jquery-ui-tabs'), Utm_Switcher::VERSION);
        }
    }

    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */
    public function add_plugin_admin_menu() {

        /*
         * Add a settings page for this plugin to the Settings menu.
         *
         * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
         *
         *        Administration Menus: http://codex.wordpress.org/Administration_Menus
         *
         * @TODO:
         *
         * - Change 'Page Title' to the title of your plugin admin page
         * - Change '$this->plugin_name' to the text for menu item for the plugin settings page
         * - Change 'manage_options' to the capability you see fit
         *   For reference: http://codex.wordpress.org/Roles_and_Capabilities
         */
        $this->plugin_screen_hook_suffix = add_options_page(
                __('Page Title', $this->plugin_slug), $this->plugin_name, 'manage_options', $this->plugin_slug, array($this, 'display_plugin_admin_page')
        );
        /*
         * Settings page in the menu
         * 
         */
        $this->plugin_screen_hook_suffix = add_menu_page(__('Page Title', $this->plugin_slug), $this->plugin_name, 'manage_options', $this->plugin_slug, array($this, 'display_plugin_admin_page'), 'dashicons-hammer', 90);
    }

    /**
     * Render the settings page for this plugin.
     *
     * @since    1.0.0
     */
    public function display_plugin_admin_page() {
        include_once( 'views/admin.php' );
    }

    /**
     * Add settings action link to the plugins page.
     *
     * @since    1.0.0
     */
    public function add_action_links($links) {
        return array_merge(
                array(
            'settings' => '<a href="' . admin_url('options-general.php?page=' . $this->plugin_slug) . '">' . __('Settings') . '</a>',
                ), $links
        );
    }

    /**
     * NOTE:     Actions are points in the execution of a page or process
     *           lifecycle that WordPress fires.
     *
     *           Actions:    http://codex.wordpress.org/Plugin_API#Actions
     *           Reference:  http://codex.wordpress.org/Plugin_API/Action_Reference
     *
     * @since    1.0.0
     */
    public function action_method_name() {
        // @TODO: Define your action hook callback here
    }

    /**
     * NOTE:     Filters are points of execution in which WordPress modifies data
     *           before saving it or sending it to the browser.
     *
     *           Filters: http://codex.wordpress.org/Plugin_API#Filters
     *           Reference:  http://codex.wordpress.org/Plugin_API/Filter_Reference
     *
     * @since    1.0.0
     */
    public function filter_method_name() {
        // @TODO: Define your filter hook callback here
    }

    public function add_tag_generator_utm() {
        if (function_exists('wpcf7_add_tag_generator')) {
            wpcf7_add_tag_generator('UTM', __('UTM', 'wpcf7'), 'utm-switcher-tag-pane', array($this, 'utm_switcher_tag_pane'));
        }
    }

    public function utm_switcher_tag_pane($contact_form, $args = "") {
        include_once( 'views/utm_switcher_tag_pane.php' );
    }

}
