<?php

/**
 * The WordPress Plugin Boilerplate.
 *
 * A foundation off of which to build well-documented WordPress plugins that
 * also follow WordPress Coding Standards and PHP best practices.
 *
 * @package   Utm_Switcher
 * @author    David Alberts and Jeff Shamley <mrrockgroin@gmail.com>
 * @license   GPL-2.0+
 * @link      https://jeffshamley.com
 * @copyright 2016 
 *
 * @wordpress-plugin
 * Plugin Name:       UTM Switcher
 * Plugin URI:        https://jeffshamley.com
 * Description:       Allows GET variables from Social Media Campaigns to modify content based on criteria. Also, adds these variables to CF7 Forms
 * Version:           1.0.0
 * Author:            David Alberts and Jeff Shamley
 * Author URI:        https://jeffshamley.com
 * Text Domain:       utm-switcher
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Domain Path:       /languages
 * WordPress-Plugin-Boilerplate-Powered: v1.1.7
 */

// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
	die;
}

require_once( plugin_dir_path( __FILE__ ) . 'vendor/autoload.php' );

/*
 * ------------------------------------------------------------------------------
 * Public-Facing Functionality
 * ------------------------------------------------------------------------------
 */
require_once( plugin_dir_path( __FILE__ ) . 'includes/load_textdomain.php' );

/*
 * Load template system
 */
require_once( plugin_dir_path( __FILE__ ) . 'includes/template.php' );

require_once( plugin_dir_path( __FILE__ ) . 'public/class-utm-switcher.php' );

register_activation_hook( __FILE__, array( 'Utm_Switcher', 'activate' ) );
register_deactivation_hook( __FILE__, array( 'Utm_Switcher', 'deactivate' ) );

/*
 * - 9999 is used for load the plugin as last for resolve some
 *   problems when the plugin use API of other plugins, remove
 *   if you don' want this
 */

add_action( 'plugins_loaded', array( 'Utm_Switcher', 'get_instance' ), 9999 );

/*
 * -----------------------------------------------------------------------------
 * Dashboard and Administrative Functionality
 * -----------------------------------------------------------------------------
*/
//Because
if ( ! defined( 'UTM_SWITCHER_PLUGIN_PATH' ) ) {
	define('UTM_SWITCHER_PLUGIN_PATH', plugin_dir_path( __FILE__ ));
}
if ( ! defined( 'UTM_SWITCHER_PLUGIN_URL' ) ) {
	define('UTM_SWITCHER_PLUGIN_URL', untrailingslashit( plugins_url( basename( plugin_dir_path( __FILE__ ) ), basename( __FILE__ ) ) ));
}

foreach ( glob( plugin_dir_path( __FILE__ )."post-types/*.php" ) as $file ){
	include_once $file;
}
foreach ( glob( plugin_dir_path( __FILE__ )."taxonomies/*.php" ) as $file ){
	include_once $file;
}


/*
 *
 * If you want to include Ajax within the dashboard, change the following
 * conditional to:
 *
 * if ( is_admin() ) {
 *   ...
 * }
 *
 */

if ( is_admin() && (!defined( 'DOING_AJAX' ) || !DOING_AJAX ) ) {
	require_once( plugin_dir_path( __FILE__ ) . 'admin/class-utm-switcher-admin.php' );
	add_action( 'plugins_loaded', array( 'Utm_Switcher_Admin', 'get_instance' ) );
}
